@@ -1,4 +1,5 @@
 from requests import Request, Session
+from requests import sessions
 from requests.packages.urllib3 import add_stderr_logger
 from requests.packages.urllib3.util.retry import Retry
 import json
@@ -56,7 +57,7 @@ class Api():
         self.header = {'Content-Type': 'application/json',
                        'Accept': 'application/json',
                        'Accept-Encoding': 'message/rfc822'}
-        self.session = Session()
+        self.sessions = []
         self.retry = Retry(connect=3, backoff_factor=0.5)
         self.adapter = HTTPAdapter(max_retries=self.retry)
         # self.session = Session()
@@ -64,15 +65,20 @@ class Api():
         # adapter = HTTPAdapter(max_retries=retry)
         # self.session.mount('http://', adapter)
 
-    def close_session(self):
-        self.session.close()
+    def get_sessions(self):
+        return len(self.sessions)
+
+    def close_session(self, id):
+        self.sessions[id].close()
+    
+    def close_all_session(self):
+        for session in self.sessions:
+            session.close()
 
     def open_new_session(self):
-        if self.session != None:
-            self.close_session()
         session = Session()
-        session.config['keep_alive'] == False
         session.mount('http://', self.adapter)
+        self.sessions.append(session)
 
 
     def __to_format(self, response):
@@ -90,7 +96,7 @@ class Api():
         if self.format == "json":
             return response.json()
 
-    def __get_data(self, url, content):
+    def __get_data(self, session_id, url, content):
         """A private method to return the requested data in the requested format
             for a given URL.
             @param self - the object pointer
@@ -98,36 +104,36 @@ class Api():
         """
         req = Request('POST',url, data=json.dumps(content), headers=self.header)
         prep = req.prepare()
-        resq = self.session.send(prep,
+        resq = self.sessions[session_id].send(prep,
         stream=None,
         verify=None
         )
         return resq 
 
-    def get_preprocess(self, content):
+    def get_preprocess(self, session_id, content):
         """Returns all of the user's accounts."""
-        return self.__get_data(self.url.preprocess_url(), content)
+        return self.__get_data(session_id, self.url.preprocess_url(), content)
 
-    def get_SentimetnPredict(self, content):
+    def get_SentimetnPredict(self, session_id, content):
         """Returns all of the user's accounts."""
-        return self.__get_data(self.url.predictSentiment_url(), content)
+        return self.__get_data(session_id, self.url.predictSentiment_url(), content)
 
-    def get_AspectWords(self, content):
+    def get_AspectWords(self, session_id, content):
         """Returns all of the user's accounts."""
-        return self.__get_data(self.url.getAspect_url(), content)
+        return self.__get_data(session_id, self.url.getAspect_url(), content)
 
-    def get_Opinion(self, content):
+    def get_Opinion(self, session_id, content):
         """Returns all of the user's accounts."""
-        return self.__get_data(self.url.getOpinion_url(), content)
+        return self.__get_data(session_id, self.url.getOpinion_url(), content)
 
-    def get_Qualifer(self, content):
+    def get_Qualifer(self, session_id, content):
         """Returns all of the user's accounts."""
-        return self.__get_data(self.url.getQualifier_url(), content)
+        return self.__get_data(session_id, self.url.getQualifier_url(), content)
     
-    def get_All(self, content):
+    def get_All(self, session_id, content):
         """Returns all."""
-        return self.__get_data(self.url.getAll_url(), content)
+        return self.__get_data(session_id, self.url.getAll_url(), content)
 
-    def get_Ct(self, content):
+    def get_Ct(self, session_id, content):
         """Trigger CT"""
-        return self.__get_data(self.url.getCt_url(), content)
\ No newline at end of file
+        return self.__get_data(session_id, self.url.getCt_url(), content)
\ No newline at end of file
